@@ -1,11 +1,13 @@
 pniam_result_t conv_pniam (pniam_item_list_t **prompts,
             pniam_item_list_t **answers);
+pniam_result_t pas_change (struct pniam_handle *handle,
+                            pniam_request_t *request);
 pniam_result_t authen (struct pniam_handle *handle,
                             pniam_request_t *request);
 pniam_result_t author (struct pniam_handle *handle,
                             pniam_request_t *request);
 pniam_result_t open_session (struct pniam_handle *handle,
-                            pniam_request_t *request);
+        pniam_request_t *request, char *hostname, int flag);
 pniam_result_t close_session (struct pniam_handle *handle,
                             pniam_request_t *request);
 pniam_result_t change (struct pniam_handle *handle,
