@@ -15,16 +15,15 @@ pniam_result_t set_groups (pniam_item_list_t *list)
 
     item = pniam_item_list_find (list, "GID");
     if ((item == NULL)||(item->data == NULL))
-	return PNIAM_SYSERR;
+        return PNIAM_SYSERR;
     val = setgid (*((gid_t *)(item->data)));
     if (val == -1)
-	return PNIAM_SYSERR;
+        return PNIAM_SYSERR;
 
     item = pniam_item_list_find (list, "SUP_GROUPS");
     if ((item == NULL)||(item->data == NULL))
         return PNIAM_SYSERR;
-    if (item->len > 0)
-    {
+    if (item->len > 0) {
         val = setgroups (item->len/sizeof (gid_t), 
 			(const gid_t *)(item->data));
         if (val == -1)
